@@ -26,7 +26,6 @@
 #include "connect.h"
 #include "extconf.h"
 
-#if HAVE_TYPE_VIRINTERFACEPTR
 static VALUE c_interface;
 
 static void interface_free(void *i)
@@ -48,7 +47,7 @@ VALUE ruby_libvirt_interface_new(virInterfacePtr i, VALUE conn)
  * call-seq:
  *   interface.undefine -> nil
  *
- * Call virInterfaceUndefine[http://www.libvirt.org/html/libvirt-libvirt-interface.html#virInterfaceUndefine]
+ * Call virInterfaceUndefine[https://libvirt.org/html/libvirt-libvirt-interface.html#virInterfaceUndefine]
  * to undefine this interface.
  */
 static VALUE libvirt_interface_undefine(VALUE i)
@@ -62,7 +61,7 @@ static VALUE libvirt_interface_undefine(VALUE i)
  * call-seq:
  *   interface.create(flags=0) -> nil
  *
- * Call virInterfaceCreate[http://www.libvirt.org/html/libvirt-libvirt-interface.html#virInterfaceCreate]
+ * Call virInterfaceCreate[https://libvirt.org/html/libvirt-libvirt-interface.html#virInterfaceCreate]
  * to start this interface.
  */
 static VALUE libvirt_interface_create(int argc, VALUE *argv, VALUE i)
@@ -81,7 +80,7 @@ static VALUE libvirt_interface_create(int argc, VALUE *argv, VALUE i)
  * call-seq:
  *   interface.destroy(flags=0) -> nil
  *
- * Call virInterfaceDestroy[http://www.libvirt.org/html/libvirt-libvirt-interface.html#virInterfaceDestroy]
+ * Call virInterfaceDestroy[https://libvirt.org/html/libvirt-libvirt-interface.html#virInterfaceDestroy]
  * to shutdown this interface.
  */
 static VALUE libvirt_interface_destroy(int argc, VALUE *argv, VALUE i)
@@ -96,12 +95,11 @@ static VALUE libvirt_interface_destroy(int argc, VALUE *argv, VALUE i)
                                    ruby_libvirt_value_to_uint(flags));
 }
 
-#if HAVE_VIRINTERFACEISACTIVE
 /*
  * call-seq:
  *   interface.active? -> [true|false]
  *
- * Call virInterfaceIsActive[http://www.libvirt.org/html/libvirt-libvirt-interface.html#virInterfaceIsActive]
+ * Call virInterfaceIsActive[https://libvirt.org/html/libvirt-libvirt-interface.html#virInterfaceIsActive]
  * to determine if this interface is currently active.
  */
 static VALUE libvirt_interface_active_p(VALUE p)
@@ -110,13 +108,12 @@ static VALUE libvirt_interface_active_p(VALUE p)
                                          ruby_libvirt_connect_get(p),
                                          interface_get(p));
 }
-#endif
 
 /*
  * call-seq:
  *   interface.name -> String
  *
- * Call virInterfaceGetName[http://www.libvirt.org/html/libvirt-libvirt-interface.html#virInterfaceGetName]
+ * Call virInterfaceGetName[https://libvirt.org/html/libvirt-libvirt-interface.html#virInterfaceGetName]
  * to retrieve the name of this interface.
  */
 static VALUE libvirt_interface_name(VALUE i)
@@ -130,7 +127,7 @@ static VALUE libvirt_interface_name(VALUE i)
  * call-seq:
  *   interface.mac -> String
  *
- * Call virInterfaceGetMACString[http://www.libvirt.org/html/libvirt-libvirt-interface.html#virInterfaceGetMACString]
+ * Call virInterfaceGetMACString[https://libvirt.org/html/libvirt-libvirt-interface.html#virInterfaceGetMACString]
  * to retrieve the MAC address of this interface.
  */
 static VALUE libvirt_interface_mac(VALUE i)
@@ -144,7 +141,7 @@ static VALUE libvirt_interface_mac(VALUE i)
  * call-seq:
  *   interface.xml_desc -> String
  *
- * Call virInterfaceGetXMLDesc[http://www.libvirt.org/html/libvirt-libvirt-interface.html#virInterfaceGetXMLDesc]
+ * Call virInterfaceGetXMLDesc[https://libvirt.org/html/libvirt-libvirt-interface.html#virInterfaceGetXMLDesc]
  * to retrieve the XML of this interface.
  */
 static VALUE libvirt_interface_xml_desc(int argc, VALUE *argv, VALUE i)
@@ -163,26 +160,22 @@ static VALUE libvirt_interface_xml_desc(int argc, VALUE *argv, VALUE i)
  * call-seq:
  *   interface.free -> nil
  *
- * Call virInterfaceFree[http://www.libvirt.org/html/libvirt-libvirt-interface.html#virInterfaceFree]
+ * Call virInterfaceFree[https://libvirt.org/html/libvirt-libvirt-interface.html#virInterfaceFree]
  * to free this interface.  The object will no longer be valid after this call.
  */
 static VALUE libvirt_interface_free(VALUE i)
 {
     ruby_libvirt_generate_call_free(Interface, i);
 }
-#endif
 
 /*
  * Class Libvirt::Interface
  */
 void ruby_libvirt_interface_init(void)
 {
-#if HAVE_TYPE_VIRINTERFACEPTR
     c_interface = rb_define_class_under(m_libvirt, "Interface", rb_cObject);
-#if HAVE_CONST_VIR_INTERFACE_XML_INACTIVE
     rb_define_const(c_interface, "XML_INACTIVE",
                     INT2NUM(VIR_INTERFACE_XML_INACTIVE));
-#endif
     rb_define_attr(c_interface, "connection", 1, 0);
 
     /* Interface object methods */
@@ -193,8 +186,5 @@ void ruby_libvirt_interface_init(void)
     rb_define_method(c_interface, "create", libvirt_interface_create, -1);
     rb_define_method(c_interface, "destroy", libvirt_interface_destroy, -1);
     rb_define_method(c_interface, "free", libvirt_interface_free, 0);
-#if HAVE_VIRINTERFACEISACTIVE
     rb_define_method(c_interface, "active?", libvirt_interface_active_p, 0);
-#endif
-#endif
 }
