@@ -26,7 +26,6 @@
 #include "connect.h"
 #include "extconf.h"
 
-#if HAVE_TYPE_VIRNETWORKPTR
 static VALUE c_network;
 
 static void network_free(void *d)
@@ -48,7 +47,7 @@ VALUE ruby_libvirt_network_new(virNetworkPtr n, VALUE conn)
  * call-seq:
  *   net.undefine -> nil
  *
- * Call virNetworkUndefine[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkUndefine]
+ * Call virNetworkUndefine[https://libvirt.org/html/libvirt-libvirt-network.html#virNetworkUndefine]
  * to undefine this network.
  */
 static VALUE libvirt_network_undefine(VALUE n)
@@ -62,7 +61,7 @@ static VALUE libvirt_network_undefine(VALUE n)
  * call-seq:
  *   net.create -> nil
  *
- * Call virNetworkCreate[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkCreate]
+ * Call virNetworkCreate[https://libvirt.org/html/libvirt-libvirt-network.html#virNetworkCreate]
  * to start this network.
  */
 static VALUE libvirt_network_create(VALUE n)
@@ -72,12 +71,11 @@ static VALUE libvirt_network_create(VALUE n)
                                    network_get(n));
 }
 
-#if HAVE_VIRNETWORKUPDATE
 /*
  * call-seq:
  *   net.update -> nil
  *
- * Call virNetworkUpdate[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkUpdate]
+ * Call virNetworkUpdate[https://libvirt.org/html/libvirt-libvirt-network.html#virNetworkUpdate]
  * to update this network.
  */
 static VALUE libvirt_network_update(VALUE n, VALUE command, VALUE section,
@@ -89,13 +87,12 @@ static VALUE libvirt_network_update(VALUE n, VALUE command, VALUE section,
                                    NUM2UINT(section), NUM2INT(index),
                                    StringValuePtr(xml), NUM2UINT(flags));
 }
-#endif
 
 /*
  * call-seq:
  *   net.destroy -> nil
  *
- * Call virNetworkDestroy[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkDestroy]
+ * Call virNetworkDestroy[https://libvirt.org/html/libvirt-libvirt-network.html#virNetworkDestroy]
  * to shutdown this network.
  */
 static VALUE libvirt_network_destroy(VALUE n)
@@ -109,7 +106,7 @@ static VALUE libvirt_network_destroy(VALUE n)
  * call-seq:
  *   net.name -> String
  *
- * Call virNetworkGetName[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkGetName]
+ * Call virNetworkGetName[https://libvirt.org/html/libvirt-libvirt-network.html#virNetworkGetName]
  * to retrieve the name of this network.
  */
 static VALUE libvirt_network_name(VALUE n)
@@ -123,7 +120,7 @@ static VALUE libvirt_network_name(VALUE n)
  * call-seq:
  *   net.uuid -> String
  *
- * Call virNetworkGetUUIDString[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkGetUUIDString]
+ * Call virNetworkGetUUIDString[https://libvirt.org/html/libvirt-libvirt-network.html#virNetworkGetUUIDString]
  * to retrieve the UUID of this network.
  */
 static VALUE libvirt_network_uuid(VALUE n)
@@ -136,7 +133,7 @@ static VALUE libvirt_network_uuid(VALUE n)
  * call-seq:
  *   net.xml_desc(flags=0) -> String
  *
- * Call virNetworkGetXMLDesc[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkGetXMLDesc]
+ * Call virNetworkGetXMLDesc[https://libvirt.org/html/libvirt-libvirt-network.html#virNetworkGetXMLDesc]
  * to retrieve the XML for this network.
  */
 static VALUE libvirt_network_xml_desc(int argc, VALUE *argv, VALUE n)
@@ -155,7 +152,7 @@ static VALUE libvirt_network_xml_desc(int argc, VALUE *argv, VALUE n)
  * call-seq:
  *   net.bridge_name -> String
  *
- * Call virNetworkGetBridgeName[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkGetBridgeName]
+ * Call virNetworkGetBridgeName[https://libvirt.org/html/libvirt-libvirt-network.html#virNetworkGetBridgeName]
  * to retrieve the bridge name for this network.
  */
 static VALUE libvirt_network_bridge_name(VALUE n)
@@ -169,7 +166,7 @@ static VALUE libvirt_network_bridge_name(VALUE n)
  * call-seq:
  *   net.autostart? -> [true|false]
  *
- * Call virNetworkGetAutostart[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkGetAutostart]
+ * Call virNetworkGetAutostart[https://libvirt.org/html/libvirt-libvirt-network.html#virNetworkGetAutostart]
  * to determine if this network will be autostarted when libvirtd starts.
  */
 static VALUE libvirt_network_autostart(VALUE n)
@@ -187,7 +184,7 @@ static VALUE libvirt_network_autostart(VALUE n)
  * call-seq:
  *   net.autostart = [true|false]
  *
- * Call virNetworkSetAutostart[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkSetAutostart]
+ * Call virNetworkSetAutostart[https://libvirt.org/html/libvirt-libvirt-network.html#virNetworkSetAutostart]
  * to set this network to be autostarted when libvirtd starts.
  */
 static VALUE libvirt_network_autostart_equal(VALUE n, VALUE autostart)
@@ -206,7 +203,7 @@ static VALUE libvirt_network_autostart_equal(VALUE n, VALUE autostart)
  * call-seq:
  *   net.free -> nil
  *
- * Call virNetworkFree[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkFree]
+ * Call virNetworkFree[https://libvirt.org/html/libvirt-libvirt-network.html#virNetworkFree]
  * to free this network.  The object will no longer be valid after this call.
  */
 static VALUE libvirt_network_free(VALUE n)
@@ -214,12 +211,11 @@ static VALUE libvirt_network_free(VALUE n)
     ruby_libvirt_generate_call_free(Network, n);
 }
 
-#if HAVE_VIRNETWORKISACTIVE
 /*
  * call-seq:
  *   net.active? -> [true|false]
  *
- * Call virNetworkIsActive[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkIsActive]
+ * Call virNetworkIsActive[https://libvirt.org/html/libvirt-libvirt-network.html#virNetworkIsActive]
  * to determine if this network is currently active.
  */
 static VALUE libvirt_network_active_p(VALUE n)
@@ -228,14 +224,12 @@ static VALUE libvirt_network_active_p(VALUE n)
                                          ruby_libvirt_connect_get(n),
                                          network_get(n));
 }
-#endif
 
-#if HAVE_VIRNETWORKISPERSISTENT
 /*
  * call-seq:
  *   net.persistent? -> [true|false]
  *
- * Call virNetworkIsPersistent[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkIsPersistent]
+ * Call virNetworkIsPersistent[https://libvirt.org/html/libvirt-libvirt-network.html#virNetworkIsPersistent]
  * to determine if this network is persistent.
  */
 static VALUE libvirt_network_persistent_p(VALUE n)
@@ -244,9 +238,7 @@ static VALUE libvirt_network_persistent_p(VALUE n)
                                          ruby_libvirt_connect_get(n),
                                          network_get(n));
 }
-#endif
 
-#if HAVE_VIRNETWORKGETDHCPLEASES
 struct leases_arg {
     virNetworkDHCPLeasePtr *leases;
     int nleases;
@@ -296,7 +288,7 @@ static VALUE leases_wrap(VALUE arg)
  * call-seq:
  *   net.dhcp_leases(mac=nil, flags=0) -> Hash
  *
- * Call virNetworkGetDHCPLeases[http://www.libvirt.org/html/libvirt-libvirt-network.html#virNetworkGetDHCPLeases]
+ * Call virNetworkGetDHCPLeases[https://libvirt.org/html/libvirt-libvirt-network.html#virNetworkGetDHCPLeases]
  * to retrieve the leases for this network.
  */
 static VALUE libvirt_network_get_dhcp_leases(int argc, VALUE *argv, VALUE n)
@@ -330,24 +322,19 @@ static VALUE libvirt_network_get_dhcp_leases(int argc, VALUE *argv, VALUE n)
 
     return result;
 }
-#endif
-
-#endif
 
 /*
  * Class Libvirt::Network
  */
 void ruby_libvirt_network_init(void)
 {
-#if HAVE_TYPE_VIRNETWORKPTR
     c_network = rb_define_class_under(m_libvirt, "Network", rb_cObject);
     rb_define_attr(c_network, "connection", 1, 0);
 
     rb_define_method(c_network, "undefine", libvirt_network_undefine, 0);
     rb_define_method(c_network, "create", libvirt_network_create, 0);
-#if HAVE_VIRNETWORKUPDATE
     rb_define_method(c_network, "update", libvirt_network_update, 5);
-#endif
+
     rb_define_method(c_network, "destroy", libvirt_network_destroy, 0);
     rb_define_method(c_network, "name", libvirt_network_name, 0);
     rb_define_method(c_network, "uuid", libvirt_network_uuid, 0);
@@ -358,13 +345,8 @@ void ruby_libvirt_network_init(void)
     rb_define_method(c_network, "autostart=", libvirt_network_autostart_equal,
                      1);
     rb_define_method(c_network, "free", libvirt_network_free, 0);
-#if HAVE_VIRNETWORKISACTIVE
     rb_define_method(c_network, "active?", libvirt_network_active_p, 0);
-#endif
-#if HAVE_VIRNETWORKISPERSISTENT
     rb_define_method(c_network, "persistent?", libvirt_network_persistent_p, 0);
-#endif
-#if HAVE_CONST_VIR_NETWORK_UPDATE_COMMAND_NONE
     /* Ideally we would just have the "UPDATE_COMMAND_NONE" constant.
      * Unfortunately we screwed up long ago, and we have to
      * leave "NETWORK_UPDATE_COMMAND_NONE" for backwards compatibility.
@@ -525,31 +507,18 @@ void ruby_libvirt_network_init(void)
                     INT2NUM(VIR_NETWORK_UPDATE_AFFECT_CONFIG));
     rb_define_const(c_network, "NETWORK_UPDATE_AFFECT_CONFIG",
                     INT2NUM(VIR_NETWORK_UPDATE_AFFECT_CONFIG));
-#endif
 
-#if HAVE_CONST_VIR_NETWORK_XML_INACTIVE
     rb_define_const(c_network, "XML_INACTIVE",
                     INT2NUM(VIR_NETWORK_XML_INACTIVE));
-#endif
-#if HAVE_CONST_VIR_NETWORK_UPDATE_COMMAND_DELETE
     rb_define_const(c_network, "UPDATE_COMMAND_DELETE",
                     INT2NUM(VIR_NETWORK_UPDATE_COMMAND_DELETE));
-#endif
 
-#if HAVE_VIRNETWORKGETDHCPLEASES
     rb_define_method(c_network, "dhcp_leases",
                      libvirt_network_get_dhcp_leases, -1);
-#endif
 
-#if HAVE_CONST_VIR_IP_ADDR_TYPE_IPV4
     rb_define_const(c_network, "IP_ADDR_TYPE_IPV4",
                     INT2NUM(VIR_IP_ADDR_TYPE_IPV4));
-#endif
 
-#if HAVE_CONST_VIR_IP_ADDR_TYPE_IPV6
     rb_define_const(c_network, "IP_ADDR_TYPE_IPV6",
                     INT2NUM(VIR_IP_ADDR_TYPE_IPV6));
-#endif
-
-#endif
 }
