@@ -26,7 +26,6 @@
 #include "connect.h"
 #include "extconf.h"
 
-#if HAVE_TYPE_VIRSTREAMPTR
 static VALUE c_stream;
 
 static void stream_free(void *s)
@@ -48,7 +47,7 @@ VALUE ruby_libvirt_stream_new(virStreamPtr s, VALUE conn)
  * call-seq:
  *   stream.send(buffer) -> Fixnum
  *
- * Call virStreamSend[http://www.libvirt.org/html/libvirt-libvirt-stream.html#virStreamSend]
+ * Call virStreamSend[https://libvirt.org/html/libvirt-libvirt-stream.html#virStreamSend]
  * to send the data in buffer out to the stream.  The return value is the
  * number of bytes sent, which may be less than the size of the buffer.  If
  * an error occurred, -1 is returned.  If the transmit buffers are full and the
@@ -72,7 +71,7 @@ static VALUE libvirt_stream_send(VALUE s, VALUE buffer)
  * call-seq:
  *   stream.recv(bytes) -> [return_value, data]
  *
- * Call virStreamRecv[http://www.libvirt.org/html/libvirt-libvirt-stream.html#virStreamRecv]
+ * Call virStreamRecv[https://libvirt.org/html/libvirt-libvirt-stream.html#virStreamRecv]
  * to receive up to bytes amount of data from the stream.  The return is an
  * array with two elements; the return code from the virStreamRecv call and
  * the data (as a String) read from the stream.  If an error occurred, the
@@ -138,7 +137,7 @@ static int internal_sendall(virStreamPtr RUBY_LIBVIRT_UNUSED(st), char *data,
  * call-seq:
  *   stream.sendall(opaque=nil){|opaque, nbytes| send block} -> nil
  *
- * Call virStreamSendAll[http://www.libvirt.org/html/libvirt-libvirt-stream.html#virStreamSendAll]
+ * Call virStreamSendAll[https://libvirt.org/html/libvirt-libvirt-stream.html#virStreamSendAll]
  * to send the entire data stream.  The send block is required and is executed
  * one or more times to send data.  Each invocation of the send block yields
  * the opaque data passed into the initial call and the number of bytes this
@@ -149,7 +148,7 @@ static int internal_sendall(virStreamPtr RUBY_LIBVIRT_UNUSED(st), char *data,
  */
 static VALUE libvirt_stream_sendall(int argc, VALUE *argv, VALUE s)
 {
-    VALUE opaque;
+    VALUE opaque = RUBY_Qnil;
     int ret;
 
     if (!rb_block_given_p()) {
@@ -184,7 +183,7 @@ static int internal_recvall(virStreamPtr RUBY_LIBVIRT_UNUSED(st),
  * call-seq:
  *   stream.recvall(opaque){|data, opaque| receive block} -> nil
  *
- * Call virStreamRecvAll[http://www.libvirt.org/html/libvirt-libvirt-stream.html#virStreamRecvAll]
+ * Call virStreamRecvAll[https://libvirt.org/html/libvirt-libvirt-stream.html#virStreamRecvAll]
  * to receive the entire data stream.  The receive block is required and is
  * called one or more times to receive data.  Each invocation of the receive
  * block yields the data received and the opaque data passed into the initial
@@ -192,7 +191,7 @@ static int internal_recvall(virStreamPtr RUBY_LIBVIRT_UNUSED(st),
  */
 static VALUE libvirt_stream_recvall(int argc, VALUE *argv, VALUE s)
 {
-    VALUE opaque;
+    VALUE opaque = RUBY_Qnil;
     int ret;
 
     if (!rb_block_given_p()) {
@@ -246,7 +245,7 @@ static void stream_event_callback(virStreamPtr st, int events, void *opaque)
  * call-seq:
  *   stream.event_add_callback(events, callback, opaque=nil) -> nil
  *
- * Call virStreamEventAddCallback[http://www.libvirt.org/html/libvirt-libvirt-stream.html#virStreamEventAddCallback]
+ * Call virStreamEventAddCallback[https://libvirt.org/html/libvirt-libvirt-stream.html#virStreamEventAddCallback]
  * to register a callback to be notified when a stream becomes readable or
  * writeable.  The events parameter is an integer representing the events the
  * user is interested in; it should be one or more of EVENT_READABLE,
@@ -259,7 +258,7 @@ static void stream_event_callback(virStreamPtr st, int events, void *opaque)
  */
 static VALUE libvirt_stream_event_add_callback(int argc, VALUE *argv, VALUE s)
 {
-    VALUE events, callback, opaque, passthrough;
+    VALUE events = RUBY_Qnil, callback = RUBY_Qnil, opaque = RUBY_Qnil, passthrough;
     int ret;
 
     rb_scan_args(argc, argv, "21", &events, &callback, &opaque);
@@ -288,7 +287,7 @@ static VALUE libvirt_stream_event_add_callback(int argc, VALUE *argv, VALUE s)
  * call-seq:
  *   stream.event_update_callback(events) -> nil
  *
- * Call virStreamEventUpdateCallback[http://www.libvirt.org/html/libvirt-libvirt-stream.html#virStreamEventUpdateCallback]
+ * Call virStreamEventUpdateCallback[https://libvirt.org/html/libvirt-libvirt-stream.html#virStreamEventUpdateCallback]
  * to change the events that the event callback is looking for.  The events
  * parameter is an integer representing the events the user is interested in;
  * it should be one or more of EVENT_READABLE, EVENT_WRITABLE, EVENT_ERROR,
@@ -305,7 +304,7 @@ static VALUE libvirt_stream_event_update_callback(VALUE s, VALUE events)
  * call-seq:
  *   stream.event_remove_callback -> nil
  *
- * Call virStreamEventRemoveCallback[http://www.libvirt.org/html/libvirt-libvirt-stream.html#virStreamEventRemoveCallback]
+ * Call virStreamEventRemoveCallback[https://libvirt.org/html/libvirt-libvirt-stream.html#virStreamEventRemoveCallback]
  * to remove the event callback currently registered to this stream.
  */
 static VALUE libvirt_stream_event_remove_callback(VALUE s)
@@ -319,7 +318,7 @@ static VALUE libvirt_stream_event_remove_callback(VALUE s)
  * call-seq:
  *   stream.finish -> nil
  *
- * Call virStreamFinish[http://www.libvirt.org/html/libvirt-libvirt-stream.html#virStreamFinish]
+ * Call virStreamFinish[https://libvirt.org/html/libvirt-libvirt-stream.html#virStreamFinish]
  * to finish this stream.  Finish is typically used when the stream is no
  * longer needed and needs to be cleaned up.
  */
@@ -333,7 +332,7 @@ static VALUE libvirt_stream_finish(VALUE s)
  * call-seq:
  *   stream.abort -> nil
  *
- * Call virStreamAbort[http://www.libvirt.org/html/libvirt-libvirt-stream.html#virStreamAbort]
+ * Call virStreamAbort[https://libvirt.org/html/libvirt-libvirt-stream.html#virStreamAbort]
  * to abort this stream.  Abort is typically used when something on the stream
  * has failed, and the stream needs to be cleaned up.
  */
@@ -347,21 +346,19 @@ static VALUE libvirt_stream_abort(VALUE s)
  * call-seq:
  *   stream.free -> nil
  *
- * Call virStreamFree[http://www.libvirt.org/html/libvirt-libvirt-stream.html#virStreamFree]
+ * Call virStreamFree[https://libvirt.org/html/libvirt-libvirt-stream.html#virStreamFree]
  * to free this stream.  The object will no longer be valid after this call.
  */
 static VALUE libvirt_stream_free(VALUE s)
 {
     ruby_libvirt_generate_call_free(Stream, s);
 }
-#endif
 
 /*
  * Class Libvirt::Stream
  */
 void ruby_libvirt_stream_init(void)
 {
-#if HAVE_TYPE_VIRSTREAMPTR
     c_stream = rb_define_class_under(m_libvirt, "Stream", rb_cObject);
 
     rb_define_attr(c_stream, "connection", 1, 0);
@@ -388,5 +385,4 @@ void ruby_libvirt_stream_init(void)
     rb_define_method(c_stream, "finish", libvirt_stream_finish, 0);
     rb_define_method(c_stream, "abort", libvirt_stream_abort, 0);
     rb_define_method(c_stream, "free", libvirt_stream_free, 0);
-#endif
 }
