@@ -2,16 +2,19 @@ $FAIL = 0
 $SUCCESS = 0
 $SKIPPED = 0
 
-$GUEST_BASE = '/var/lib/libvirt/images/ruby-libvirt-tester'
+URI = ENV['RUBY_LIBVIRT_TEST_URI'] || "qemu:///system"
+
+$GUEST_BASE = '/var/lib/libvirt/images/rb-libvirt-test'
 $GUEST_DISK = $GUEST_BASE + '.qcow2'
 $GUEST_SAVE = $GUEST_BASE + '.save'
 $GUEST_UUID = "93a5c045-6457-2c09-e56f-927cdf34e17a"
+$GUEST_RAW_DISK = $GUEST_BASE + '.raw'
 
 # XML data for later tests
 $new_dom_xml = <<EOF
 <domain type='kvm'>
   <description>Ruby Libvirt Tester</description>
-  <name>ruby-libvirt-tester</name>
+  <name>rb-libvirt-test</name>
   <uuid>#{$GUEST_UUID}</uuid>
   <memory>1048576</memory>
   <currentMemory>1048576</currentMemory>
@@ -57,11 +60,11 @@ $new_dom_xml = <<EOF
 EOF
 
 # qemu command-line that roughly corresponds to the above XML
-$qemu_cmd_line = "/usr/bin/qemu-kvm -S -M pc-0.13 -enable-kvm -m 1024 -smp 1,sockets=1,cores=1,threads=1 -name ruby-libvirt-tester -uuid #{$GUEST_UUID} -nodefconfig -nodefaults -chardev socket,id=monitor,path=/var/lib/libvirt/qemu/ruby-libvirt-tester.monitor,server,nowait -mon chardev=monitor,mode=readline -rtc base=utc -boot c -chardev pty,id=serial0 -device isa-serial,chardev=serial0 -usb -vnc 127.0.0.1:0 -k en-us -vga cirrus -device virtio-balloon-pci,id=balloon0,bus=pci.0,addr=0x5"
+$qemu_cmd_line = "/usr/bin/qemu-kvm -S -M pc-0.13 -enable-kvm -m 1024 -smp 1,sockets=1,cores=1,threads=1 -name rb-libvirt-test -uuid #{$GUEST_UUID} -nodefconfig -nodefaults -chardev socket,id=monitor,path=/var/lib/libvirt/qemu/rb-libvirt-test.monitor,server,nowait -mon chardev=monitor,mode=readline -rtc base=utc -boot c -chardev pty,id=serial0 -device isa-serial,chardev=serial0 -usb -vnc 127.0.0.1:0 -k en-us -vga cirrus -device virtio-balloon-pci,id=balloon0,bus=pci.0,addr=0x5"
 
 $NEW_INTERFACE_MAC = 'aa:bb:cc:dd:ee:ff'
 $new_interface_xml = <<EOF
-<interface type="ethernet" name="ruby-libvirt-tester">
+<interface type="ethernet" name="rb-libvirt-test">
   <start mode="onboot"/>
   <mac address="#{$NEW_INTERFACE_MAC}"/>
   <protocol family='ipv4'>
@@ -73,7 +76,7 @@ EOF
 $NETWORK_UUID = "04068860-d9a2-47c5-bc9d-9e047ae901da"
 $new_net_xml = <<EOF
 <network>
-  <name>ruby-libvirt-tester</name>
+  <name>rb-libvirt-test</name>
   <uuid>#{$NETWORK_UUID}</uuid>
   <forward mode='nat'/>
   <bridge name='rubybr0' stp='on' delay='0' />
@@ -91,7 +94,7 @@ EOF
 
 $NWFILTER_UUID = "bd339530-134c-6d07-441a-17fb90dad807"
 $new_nwfilter_xml = <<EOF
-<filter name='ruby-libvirt-tester' chain='ipv4'>
+<filter name='rb-libvirt-test' chain='ipv4'>
   <uuid>#{$NWFILTER_UUID}</uuid>
   <rule action='accept' direction='out' priority='100'>
     <ip srcipaddr='0.0.0.0' dstipaddr='255.255.255.255' protocol='tcp' srcportstart='63000' dstportstart='62000'/>
@@ -114,10 +117,10 @@ $new_secret_xml = <<EOF
 EOF
 
 $POOL_UUID = "33a5c045-645a-2c00-e56b-927cdf34e17a"
-$POOL_PATH = "/var/lib/libvirt/images/ruby-libvirt-tester"
+$POOL_PATH = "/var/lib/libvirt/images/rb-libvirt-test"
 $new_storage_pool_xml = <<EOF
 <pool type="dir">
-  <name>ruby-libvirt-tester</name>
+  <name>rb-libvirt-test</name>
   <uuid>#{$POOL_UUID}</uuid>
   <target>
     <path>#{$POOL_PATH}</path>
@@ -163,6 +166,24 @@ def expect_fail(object, errtype, errmsg, func, *args)
   end
 end
 
+def expect_utf8_exception_msg(object, errtype, func, *args)
+  begin
+    object.__send__(func, *args)
+  rescue NoMethodError
+    puts_skipped "#{$test_object}.#{func} does not exist"
+  rescue errtype => e
+    if e.message.encoding.name == 'UTF-8'
+      puts_ok "#{$test_object}.#{func} threw #{errtype.to_s} with UTF-8 encoding"
+    else
+      puts_fail "#{$test_object}.#{func} threw #{errtype.to_s} with #{e.message.encoding.name} encoding"
+    end
+  rescue => e
+    puts_fail "#{$test_object}.#{func} expected to throw #{errtype.to_s}, but instead threw #{e.class.to_s}: #{e.to_s}"
+  else
+    puts_fail "#{$test_object}.#{func} expected to throw #{errtype.to_s}, but threw nothing"
+  end
+end
+
 def expect_too_many_args(object, func, *args)
   expect_fail(object, ArgumentError, "too many args", func, *args)
 end
@@ -208,7 +229,7 @@ end
 def cleanup_test_domain(conn)
   # cleanup from previous runs
   begin
-    olddom = conn.lookup_domain_by_name("ruby-libvirt-tester")
+    olddom = conn.lookup_domain_by_name("rb-libvirt-test")
   rescue
     # in case we didn't find it, don't do anything
   end
@@ -232,7 +253,7 @@ end
 def cleanup_test_network(conn)
   # initial cleanup for previous run
   begin
-    oldnet = conn.lookup_network_by_name("ruby-libvirt-tester")
+    oldnet = conn.lookup_network_by_name("rb-libvirt-test")
   rescue
     # in case we didn't find it, don't do anything
   end
